@@ -18,9 +18,9 @@ import tempfile
 import shutil
 import socket
 
-from ioflo.base.odicting import odict
-from ioflo.base.aiding import Timer, StoreTimer
-from ioflo.base import storing
+from ioflo.aid.odicting import odict
+from ioflo.aid.timing import Timer, StoreTimer
+from ioflo.base.storing import Store
 from ioflo.base.consoling import getConsole
 console = getConsole()
 
@@ -46,7 +46,7 @@ class BasicTestCase(unittest.TestCase):
     """"""
 
     def setUp(self):
-        self.store = storing.Store(stamp=0.0)
+        self.store = Store(stamp=0.0)
         self.timer = StoreTimer(store=self.store, duration=1.0)
 
         self.base = tempfile.mkdtemp(prefix="raet",  suffix="base", dir=TEMPDIR)
